"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var dom = require("../util/dom");
var _ = require("lodash");
var GenericCompletionPopup = /** @class */ (function () {
    function GenericCompletionPopup(relativeRootElement, editor) {
        this.relativeRootElement = relativeRootElement;
        this.editor = editor;
        this.currentFocus = 0;
        this.completionDomElements = [];
        this.onCancel = function () { return null; };
        this.onSelected = function (___) { return null; };
        this.afterSelection = function (___) { return null; };
    }
    GenericCompletionPopup.prototype.hasHints = function () {
        return this.completionDomElements.length > 0;
    };
    GenericCompletionPopup.prototype.removeCompletions = function () {
        this.completionDomElements.forEach(function (el) {
            el.parentNode.removeChild(el);
        });
        this.completionDomElements = [];
        if (!_.isNil(this.completionsElement)) {
            dom.removeElement(this.completionsElement);
        }
    };
    GenericCompletionPopup.prototype.choosePrevCompletion = function () {
        this.currentFocus--;
        this.renderActive();
    };
    GenericCompletionPopup.prototype.chooseNextCompletion = function () {
        this.currentFocus++;
        this.renderActive();
    };
    GenericCompletionPopup.prototype.removeCurrentFocus = function () {
        this.currentFocus = -1;
        this.removeActive();
    };
    GenericCompletionPopup.prototype.cancel = function () {
        this.removeCompletions();
        this.onCancel();
    };
    GenericCompletionPopup.prototype.select = function () {
        var hintEl = this.completionDomElements[this.currentFocus];
        if (hintEl) {
            hintEl.click();
            return true;
        }
        return false;
    };
    GenericCompletionPopup.prototype.showHints = function (inputElement, completions) {
        var _this = this;
        if (!completions) {
            return;
        }
        this.relativeInputElement = inputElement;
        this.removeCompletions();
        this.completionsElement = dom.createElement('ul', this.completionsCssClass + " antlr__search-hints");
        this.relativeRootElement.appendChild(this.completionsElement);
        completions.forEach(function (completion) {
            var el = document.createElement('li');
            el.className = _this.singleCompletionCssClass;
            el.addEventListener('click', function (evt) {
                evt.preventDefault();
                // evt.stopPropagation();
                _this.onSelected(completion);
                _this.removeCompletions();
                if (completion.range && completion.text) {
                    _this.editor.replaceRange(completion.range, completion.text);
                    _.each(completion.placeholderFactoryMethods, function (func, varName) {
                        completion.placeholders[varName] = func();
                    });
                }
                _this.afterSelection(completion);
            });
            _this.completionDomElements.push(el);
            _this.completionsElement.appendChild(el);
            if (completion.onRender) {
                completion.onRender(el);
                return;
            }
            if (completion.displayText) {
                el.innerText = completion.displayText;
                return;
            }
            el.innerText = completion.text;
        }, true);
        this.renderActive();
        this.positionHintsElement();
    };
    GenericCompletionPopup.prototype.positionHintsElement = function () {
        if (this.relativeInputElement) {
            var position = dom.getPosition(this.relativeInputElement, this.relativeRootElement);
            dom.setPosition(this.completionsElement, position);
        }
    };
    GenericCompletionPopup.prototype.renderActive = function () {
        this.removeActive();
        this.adjustCurrentFocus();
        if (this.completionDomElements.length > 0) {
            var el = this.completionDomElements[this.currentFocus];
            if (!_.isNil(el)) {
                dom.addClass(el, this.activeCompletionCssClass);
            }
        }
    };
    GenericCompletionPopup.prototype.removeActive = function () {
        var _this = this;
        this.completionDomElements.forEach(function (el) {
            dom.removeClass(el, _this.activeCompletionCssClass);
        });
    };
    GenericCompletionPopup.prototype.adjustCurrentFocus = function () {
        if (this.currentFocus >= this.completionDomElements.length) {
            this.currentFocus = 0;
        }
        if (this.currentFocus < 0) {
            this.currentFocus = this.completionDomElements.length - 1;
        }
    };
    return GenericCompletionPopup;
}());
exports.GenericCompletionPopup = GenericCompletionPopup;
//# sourceMappingURL=generic-completion-popup.js.map